Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(113)

Unified Diff: ios/chrome/browser/ui/tools_menu/tools_menu_configuration.h

Issue 2714813002: [iOS] Add Request Mobile Site cell to tools menu (Closed)
Patch Set: Fix unit test Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/chrome/browser/ui/tools_menu/tools_menu_configuration.h
diff --git a/ios/chrome/browser/ui/tools_menu/tools_menu_context.h b/ios/chrome/browser/ui/tools_menu/tools_menu_configuration.h
similarity index 67%
rename from ios/chrome/browser/ui/tools_menu/tools_menu_context.h
rename to ios/chrome/browser/ui/tools_menu/tools_menu_configuration.h
index 2560f5feb87023a8b2fcde4ba9e68ae9fc9005c8..1c485c6b9f874bcacf39611c8982b07f5e6fb704 100644
--- a/ios/chrome/browser/ui/tools_menu/tools_menu_context.h
+++ b/ios/chrome/browser/ui/tools_menu/tools_menu_configuration.h
@@ -10,15 +10,27 @@
@class ReadingListMenuNotifier;
-// Context defining options that can be set to change the tools menu's
-// appearance. All are set to false by default.
-@interface ToolsMenuContext : NSObject
-// Indicate that the menu is being shown while in the tab switcher.
+namespace web {
+enum class UserAgentType : short;
+} // namespace web
+
+// Configuation defining options that can be set to change the tools menu's
+// appearance. All boolean properties are set to NO, and |userAgentType| is set
+// to NONE by default.
+@interface ToolsMenuConfiguration : NSObject
+// Indicates that the menu is being shown while in the tab switcher.
@property(nonatomic, getter=isInTabSwitcher) BOOL inTabSwitcher;
-// Indicate that the menu is being shown while there are no open tabs.
+// Indicates that the menu is being shown while there are no open tabs.
@property(nonatomic, getter=hasNoOpenedTabs) BOOL noOpenedTabs;
-// Indicate that the menu is being shown while in incognito mode.
+// Indicates that the menu is being shown while in incognito mode.
@property(nonatomic, getter=isInIncognito) BOOL inIncognito;
+
+// Indicates that the menu is being shown while user agent is |userAgentType|.
+// If NONE, shows "Request Desktop Site" in disabled state.
+// If MOBILE, shows "Request Desktop Site" in enabled state.
+// If DESKTOP, shows "Request Mobile Site" in enabled state.
+@property(nonatomic, assign) web::UserAgentType userAgentType;
+
// View that the menu will be displayed in.
@property(nonatomic, readonly) UIView* displayView;
// Button from which popup menu will be opened.

Powered by Google App Engine
This is Rietveld 408576698